@@ -1,3 +1,5 @@
+import random
+
 class James:
     """
     คลาส james คือ
@@ -27,9 +29,7 @@ class James:
 
     def show_page(self):
         print('FB page {}'.format(self.page))
-
-        
-
+   
     def about(self):
         text = """ 
         #--------------------------------#
@@ -52,6 +52,13 @@ class James:
           """
         print(text)
 
+    def dice(self):
+        dice_list = ['⚀','⚁','⚂','⚃','⚄','⚅']
+        first = random.choice(dice_list)
+        second = random.choice(dice_list)
+        print('คุณทอยเต๋าได้: {}'.format(first,second))
+
+
 if __name__ == '__main__':
     jm = James()
     jm.show_name()
@@ -59,4 +66,5 @@ if __name__ == '__main__':
     jm.show_page()
     jm.about()
     jm.show_art()
+    jm.dice()
 
